@@ -55,14 +55,19 @@
 
 #include <float.h>
 #include <fstream>
+#include <cstring>
 
 // OpenMesh
-#include <OpenMesh/Core/System/config.h>
 #include <OpenMesh/Core/IO/BinaryHelper.hh>
 #include <OpenMesh/Core/IO/reader/STLReader.hh>
 #include <OpenMesh/Core/IO/IOManager.hh>
-#include <OpenMesh/Core/System/omstream.hh>
-#include <OpenMesh/Core/IO/importer/BaseImporter.hh>
+
+//comppare strings crossplatform ignorign case
+#ifdef _WIN32
+  #define strnicmp _strnicmp
+#else
+  #define strnicmp strncasecmp
+#endif
 
 
 //=== NAMESPACES ==============================================================
@@ -171,7 +176,7 @@ class CmpVec
 {
 public:
 
-  CmpVec(float _eps=FLT_MIN) : eps_(_eps) {}
+  explicit CmpVec(float _eps=FLT_MIN) : eps_(_eps) {}
 
   bool operator()( const Vec3f& _v0, const Vec3f& _v1 ) const
   {
@@ -450,41 +455,62 @@ _STLReader_::STL_Type
 _STLReader_::
 check_stl_type(const std::string& _filename) const
 {
-  // assume it's binary stl, then file size is known from #triangles
-  // if size matches, it's really binary
+
+   // open file
+   std::ifstream ifs (_filename.c_str(), std::ifstream::binary);
+   if(!ifs.good())
+   {
+     omerr() << "could not open file" << _filename << std::endl;
+     return NONE;
+   }
+
+   //find first non whitespace character
+   std::string line = "";
+   std::size_t firstChar;
+   while(line.empty() && ifs.good())
+   {
+     std::getline(ifs,line);
+     firstChar = line.find_first_not_of("\t ");
+   }
+
+   //check for ascii keyword solid
+   if(strnicmp("solid",&line[firstChar],5) == 0)
+   {
+     return STLA;
+   }
+   ifs.close();
+
+   //if the file does not start with solid it is probably STLB
+   //check the file size to verify it.
+
+   //open the file
+   FILE* in = fopen(_filename.c_str(), "rb");
+   if (!in) return NONE;
+
+   // determine endian mode
+   union { unsigned int i; unsigned char c[4]; } endian_test;
+   endian_test.i = 1;
+   bool swapFlag = (endian_test.c[3] == 1);
 
 
-  // open file
-  FILE* in = fopen(_filename.c_str(), "rb");
-  if (!in) return NONE;
+   // read number of triangles
+   char dummy[100];
+   fread(dummy, 1, 80, in);
+   size_t nT = read_int(in, swapFlag);
 
 
-  // determine endian mode
-  union { unsigned int i; unsigned char c[4]; } endian_test;
-  endian_test.i = 1;
-  bool swapFlag = (endian_test.c[3] == 1);
+   // compute file size from nT
+   size_t binary_size = 84 + nT*50;
 
+   // get actual file size
+   size_t file_size(0);
+   rewind(in);
+   while (!feof(in))
+     file_size += fread(dummy, 1, 100, in);
+   fclose(in);
 
-  // read number of triangles
-  char dummy[100];
-  fread(dummy, 1, 80, in);
-  size_t nT = read_int(in, swapFlag);
-
-
-  // compute file size from nT
-  size_t binary_size = 84 + nT*50;
-
-
-  // get actual file size
-  size_t file_size(0);
-  rewind(in);
-  while (!feof(in))
-    file_size += fread(dummy, 1, 100, in);
-  fclose(in);
-
-
-  // if sizes match -> it's STLB
-  return (binary_size == file_size ? STLB : STLA);
+   // if sizes match -> it's STLB
+      return (binary_size == file_size ? STLB : NONE);
 }
 
 
